==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/nds.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivität",
    "Personal activity feed for %s" : "Persönliche Benachrichtigungen für die Aktivität von %s",
    "Your feed URL is invalid" : "Deine URL für die Benachrichtigungen ist ungültig",
    "Your settings have been updated." : "Deine Einstellungen wurden aktualisiert.",
    "Mail" : "E-Mail",
    "Stream" : "Stream",
    "Activities" : "Aktivitäten",
    "Error loading activities" : "Fehler beim Laden der Aktivitäten",
    "No activities" : "Keine Aktivitäten",
    "This stream will show events like additions, changes & shares" : "Dieser Stream wird Ereignisse wie Hinzufügen, Änderungen und Teilen anzeigen",
    "There are no events for this filter" : "Für diesen Filter gibt es keine Ereignisse",
    "Activity notification" : "Aktivitätsbenachrichtigung",
    "All Activities" : "Alle Aktivitäten",
    "Activities by you" : "Aktivitäten von Dir",
    "Activities by others" : "Aktivitäten von Anderen",
    "\"remote user\"" : "\"Entfernter Benutzer\"",
    "%s and %s" : "%s und %s",
    ", " : ",",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s und <strong %s>%n weiteres</strong>","%s und <strong %s>%n weitere</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s und %n weiteres","%s und %n weitere"],
    "Hello %s," : "Hallo %s,",
    "You are receiving this email because the following things happened at %s" : "Du erhälst diese E-Mail, da folgende Dinge bei %s passiert sind",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* und %n weiteres","* und %n weitere"],
    "Notifications" : "Benachrichtigungen",
    "List your own actions in the stream" : "Zeige Deinen eigenen Aktionen im Stream",
    "Notify about your own actions via email" : "Benachrichtigungen über deine eigenen Aktivitäten mittels E-Mail",
    "You need to set up your email address before you can receive notification emails." : "Du musst deine E-Mailadresse eintragen, bevor du E-Mailbenachrichtigungen erhalten kannst.",
    "Send emails:" : "Sende E-Mails:",
    "Hourly" : "Stündlich",
    "Daily" : "Täglich",
    "Weekly" : "Wöchentlich",
    "Activity feed" : "Aktivitätsbenachrichtigungen",
    "Enable RSS feed" : "RSS Benachrichtigungen aktivieren",
    "No activity yet" : "Bisher keine Aktivitäten",
    "No more events to load" : "Es gibt keine Ereignisse mehr, die geladen werden können",
    "Files" : "Dateien",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s und <strong class=\"has-tooltip\" title=\"%s\">%n weiteres</strong>","%s und <strong class=\"has-tooltip\" title=\"%s\">%n weitere</strong>"]
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/nds.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivität",
    "Personal activity feed for %s" : "Persönliche Benachrichtigungen für die Aktivität von %s",
    "Your feed URL is invalid" : "Deine URL für die Benachrichtigungen ist ungültig",
    "Your settings have been updated." : "Deine Einstellungen wurden aktualisiert.",
    "Mail" : "E-Mail",
    "Stream" : "Stream",
    "Activities" : "Aktivitäten",
    "Error loading activities" : "Fehler beim Laden der Aktivitäten",
    "No activities" : "Keine Aktivitäten",
    ", " : ",",
    "This stream will show events like additions, changes & shares" : "Dieser Stream wird Ereignisse wie Hinzufügen, Änderungen und Teilen anzeigen",
    "There are no events for this filter" : "Für diesen Filter gibt es keine Ereignisse",
    "Today" : "Heute",
    "Yesterday" : "Gestern",
    "\"remote user\"" : "\"Entfernter Benutzer\"",
    "Activity notification" : "Aktivitätsbenachrichtigung",
    "All Activities" : "Alle Aktivitäten",
    "Activities by you" : "Aktivitäten von Dir",
    "Activities by others" : "Aktivitäten von Anderen",
    "%s and %s" : "%s und %s",
    "Hello %s," : "Hallo %s,",
    "You are receiving this email because the following things happened at %s" : "Du erhältst diese E-Mail, da folgende Dinge bei %s passiert sind",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* und %n weiteres","* und %n weitere"],
    "List your own actions in the stream" : "Zeige Deinen eigenen Aktionen im Stream",
    "Notify about your own actions via email" : "Benachrichtigungen über deine eigenen Aktivitäten mittels E-Mail",
    "You need to set up your email address before you can receive notification emails." : "Du musst deine E-Mailadresse eintragen, bevor du E-Mailbenachrichtigungen erhalten kannst.",
    "Send emails:" : "Sende E-Mails:",
    "Hourly" : "Stündlich",
    "Daily" : "Täglich",
    "Weekly" : "Wöchentlich",
    "Activity feed" : "Aktivitätsbenachrichtigungen",
    "Enable RSS feed" : "RSS Benachrichtigungen aktivieren",
    "No activity yet" : "Bisher keine Aktivitäten",
    "No more events to load" : "Es gibt keine Ereignisse mehr, die geladen werden können",
    "Files" : "Dateien"
},
"nplurals=2; plural=(n != 1);");
